@@ -7,7 +7,7 @@ class MissionInputObjectInfo(ObjectInfo):
     the source mission id of the input light curve.
     """
     def __init__(self, mission_id, input_file, initial_mask=None, initial_transit_mask=None,
-                 star_info=None, aperture_file=None, outliers_sigma=None,
+                 star_info=None, aperture_file=None, outliers_sigma=3,
                  high_rms_enabled=True, high_rms_threshold=2.5,
                  high_rms_bin_hours=4, smooth_enabled=False,
                  auto_detrend_enabled=False, auto_detrend_method="cosine", auto_detrend_ratio=0.25,
